# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2018-01-30 10:27
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings

import simplejson


def determine_types(apps, schema_editor):
    '''Refreshes each database so datasets/outputs are recreated'''

    Algorithm = apps.get_model("algorithms", "Algorithm")

    if Algorithm.objects.count():
        print('')

    for algorithm in Algorithm.objects.order_by('id'):
        print("Determining type of algorithm '%s/%s/%d'..." % \
                (algorithm.author.username, algorithm.name, algorithm.version))

        print(algorithm.declaration_file.path)

        with open(algorithm.declaration_file.path, 'r') as f:
            declaration = simplejson.load(f)

        if 'type' in declaration:
            if declaration['type'] == 'sequential':
                algorithm.type = 'S'
            elif declaration['type'] == 'autonomous':
                algorithm.type = 'A'
            else:
                algorithm.type = 'L'
        else:
            algorithm.type = 'L'

        algorithm.save()


class Migration(migrations.Migration):

    dependencies = [
        ('algorithms', '0003_auto_20161123_1218'),
    ]

    operations = [
        migrations.AddField(
            model_name='algorithm',
            name='type',
            field=models.CharField(choices=[(b'L', b'Legacy'), (b'S', b'Sequential'), (b'A', b'Autonomous')], default=b'S', max_length=1),
        ),
        migrations.RunPython(determine_types),
    ]
