#!/usr/bin/env python
# vim: set fileencoding=utf-8 :

###############################################################################
#                                                                             #
# Copyright (c) 2017 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.web module of the BEAT platform.              #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################


from django.db import models


#----------------------------------------------------------


class SlotManager(models.Manager):

    def get_by_natural_key(self, queue_name, worker_name):
        return self.get(queue__name=queue_name, worker__name=worker_name)


#----------------------------------------------------------


class Slot(models.Model):

    queue = models.ForeignKey('Queue', related_name='slots', on_delete=models.CASCADE)

    worker = models.ForeignKey('Worker', related_name='slots', on_delete=models.CASCADE)

    quantity = models.PositiveIntegerField(
        'Number of slots',
        help_text='Number of processing slots to dedicate in this worker for a given queue'
    )

    priority = models.PositiveIntegerField(
        default=0,
        help_text='Priority of these slots on the defined queue'
    )


    objects = SlotManager()


    #_____ Meta parameters __________

    class Meta:
        unique_together = ('queue', 'worker')


    #_____ Overrides __________

    def __str__(self):
        return '%s - %s (slots: %d, priority: %d)' % (self.queue, self.worker,
                                                      self.quantity, self.priority)


    def natural_key(self):
        return (self.queue.name, self.worker.name)
