#!/usr/bin/env python
# vim: set fileencoding=utf-8 :

###############################################################################
#                                                                             #
# Copyright (c) 2019 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.web module of the BEAT platform.              #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################

from django.core.management.base import BaseCommand

from ...models import Database


class Command(BaseCommand):

    help = "Prints the list of databases with access level and user information"

    def add_arguments(self, parser):
        parser.add_argument(
            "--folder-filter",
            action="store",
            dest="folder_filter",
            default=None,
            help="Path element up to which the the string must be cleaned",
        )

    def handle(self, *ignored, **options):

        self.stdout.write("name, access, folder, user")

        for database in Database.objects.all():
            folder = database.declaration["root_folder"]
            folder_filter = options["folder_filter"]
            if folder_filter:
                try:
                    start = folder.rindex(folder_filter) + len(folder_filter)
                except ValueError:
                    start = 0
                folder = folder[start:]

            db_info = "{}, {}, {}".format(
                database.fullname(), database.get_sharing_display(), folder
            )

            for user in [
                "{}: {} {}".format(user.username, user.first_name, user.last_name)
                for user in database.all_shared_with_users()
            ]:
                self.stdout.write("{}, {}".format(db_info, user))
            else:
                self.stdout.write(db_info)
