/*
 * Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/
 * Contact: beat.support@idiap.ch
 *
 * This file is part of the beat.web module of the BEAT platform.
 *
 * Commercial License Usage
 * Licensees holding valid commercial BEAT licenses may use this file in
 * accordance with the terms contained in a written agreement between you
 * and Idiap. For further information contact tto@idiap.ch
 *
 * Alternatively, this file may be used under the terms of the GNU Affero
 * Public License version 3 as published by the Free Software and appearing
 * in the file LICENSE.AGPL included in the packaging of this file.
 * The BEAT platform is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * You should have received a copy of the GNU Affero Public License along
 * with the BEAT platform. If not, see http://www.gnu.org/licenses/.
 */

/*
 * reportLock
 * Desc:
 *  Displays a modal for locking the current report.
 */
angular.module('reportApp')
.directive("reportLock", ['ReportService', 'ErrorService', 'GroupsService', 'ExperimentsService', function(ReportService, ErrorService, GroupsService, ExperimentsService){
    return {
        scope: {
		saveReport: '=saveReport',
        },
        restrict: 'E',
        link: function(scope, el){
		scope.expNames = ExperimentsService.experimentNames;
		scope.groups = GroupsService.groups;
		const calcUnusedExperiments = () => {
			const usedExps = Array.from(new Set([].concat.apply([], scope.groups.map(g => g.experiments))));
			const unusedExps = scope.expNames.filter(n => !usedExps.includes(n));
			scope.unusedExps = unusedExps.length !== 0;
		};
		scope.$watchCollection('expNames', (names) => {calcUnusedExperiments();});
		scope.$watch('groups', () => {calcUnusedExperiments();}, true);

            // sends the request to lock the report
            scope.lockReport = () => {
		return scope.saveReport()
		.then(() => ReportService.lockReport())
                .then(() => {window.location.reload();})
                .catch(e => {
                    ErrorService.logError(e, `Could not lock the report.`);
                });
            }
        },
        template: `
<div>
<bootstrap-modal dom-id='lockReportModal' button-submit-text='Lock' button-submit-func='lockReport' ng-if='!unusedExps'>
    <b-title>
        Lock Report
    </b-title>
    <b-content>
        <p>Locking your report is the first step for publication.</p>
        <p>Your report will not be editable anymore.</p>
        <p>In order to do lock your report, your experiments will be locked as well, if they are not already (they will not be able to be edited or deleted).</p>
    </b-content>
</bootstrap-modal>
<bootstrap-modal dom-id='lockReportModal' ng-if='unusedExps'>
    <b-title>
        Lock Report
    </b-title>
    <b-content>
        <p>There are experiments that haven't been added to a group.</p>
        <p>Please make sure every experiment is in a group, or remove experiments from the report that aren't needed.</p>
    </b-content>
</bootstrap-modal>
</div>
`
    };
}]);
