#!/usr/bin/env python
# vim: set fileencoding=utf-8 :

###############################################################################
#                                                                             #
# Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.web module of the BEAT platform.              #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################

# Django settings for tests
import os
import platform

from .settings import *  # noqa

URL_PREFIX = ""

TEST_CONFIGURATION = True
RUNNING_ON_CI = False

DEBUG = False
TEMPLATES[0]["OPTIONS"]["debug"] = DEBUG  # noqa

ALLOWED_HOSTS = ["testserver"]

if platform.system() == "Linux":
    shm_path = "/dev/shm/beatweb"  # nosec
    if not os.path.exists(shm_path):
        os.makedirs(shm_path)

    database_name = os.path.join(shm_path, "test.sqlite3")
else:
    database_name = "test.sqlite3"
DATABASES["default"]["NAME"] = database_name  # noqa
DATABASES["default"]["TEST"] = {"NAME": DATABASES["default"]["NAME"]}  # noqa
DATABASES["default"]["OPTIONS"]["timeout"] = 30  # noqa
DATABASES["default"]["ATOMIC_REQUESTS"] = True  # noqa

# Timeout used in test when waiting for an update
DB_REFRESH_TIMEOUT = int(os.environ.get("DB_REFRESH_TIMEOUT", 10))

LOGGING["handlers"]["console"]["level"] = "DEBUG"  # noqa
LOGGING["loggers"]["beat.core"]["handlers"] = ["discard"]  # noqa
LOGGING["loggers"]["beat.web"]["handlers"] = ["discard"]  # noqa
LOGGING["loggers"]["beat.web.utils.management.commands"]["handlers"] = [  # noqa
    "discard"
]

BASE_DIR = os.path.dirname(os.path.abspath(__name__))
if platform.system() == "Linux":
    default_prefix = os.path.join(shm_path, "test_prefix")  # nosec
else:
    default_prefix = os.path.realpath("./test_prefix")
PREFIX = os.environ.get("BEAT_TEST_PREFIX", default_prefix)
ALGORITHMS_ROOT = os.path.join(PREFIX, "algorithms")
PLOTTERS_ROOT = os.path.join(PREFIX, "plotters")
LIBRARIES_ROOT = os.path.join(PREFIX, "libraries")
DATABASES_ROOT = os.path.join(PREFIX, "databases")
DATAFORMATS_ROOT = os.path.join(PREFIX, "dataformats")
TOOLCHAINS_ROOT = os.path.join(PREFIX, "toolchains")
EXPERIMENTS_ROOT = os.path.join(PREFIX, "experiments")
CACHE_ROOT = os.path.join(PREFIX, "cache")

LOCAL_SCHEDULER_VERBOSITY = None
LOCAL_SCHEDULER_USE_DOCKER = False

# To speed-up tests, don't put this in production
PASSWORD_HASHERS = ["django.contrib.auth.hashers.MD5PasswordHasher"]
