#!/usr/bin/env python
# vim: set fileencoding=utf-8 :
# encoding: utf-8

###############################################################################
#                                                                             #
# Copyright (c) 2019 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.web module of the BEAT platform.              #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################

import socket

from django.core.management.base import BaseCommand
from django.conf import settings

from beat.core.bcp import worker
from beat.core.utils import setup_logging


class Command(BaseCommand):

    help = "Start zmq worker"

    def add_arguments(self, parser):
        parser.add_argument(
            "--name",
            "-n",
            type=str,
            dest="service_name",
            default=socket.gethostname(),
            help="Service name",
        )
        parser.add_argument(
            "--broker",
            "-b",
            type=str,
            dest="broker_address",
            default="tcp://localhost:5555",
            help="Broker address",
        )
        parser.add_argument(
            "--docker",
            "-d",
            action="store_true",
            dest="use_docker",
            default=False,
            help="Use docker",
        )
        parser.add_argument(
            "--prefix", "-p", dest="prefix", default=settings.PREFIX, help="Prefix path"
        )
        parser.add_argument(
            "--cache",
            "-c",
            type=str,
            dest="cache",
            default=settings.CACHE_ROOT,
            help="Cache path",
        )
        parser.add_argument(
            "--network-name",
            dest="network_name",
            type=str,
            default=None,
            help="Docker network name",
        )
        parser.add_argument(
            "--port-range",
            dest="port_range",
            type=str,
            default=None,
            help="Docker port range",
        )
        parser.add_argument(
            "--docker-images-cache",
            dest="docker_images_cache",
            type=str,
            default=None,
            help="Docker image cache",
        )

    def handle(self, *args, **options):
        verbosity = options["verbosity"]
        logger = setup_logging(verbosity, "Worker", __name__)
        logger.info("starting worker")

        argv = [
            "--name=" + options["service_name"],
            "--prefix=" + options["prefix"],
            "--cache=" + options["cache"],
        ]

        argv.extend(["-v" for i in range(options["verbosity"])])

        if options["use_docker"]:
            argv.append("--docker")

            network_name = options.get("network_name")
            if network_name:
                argv.append("--docker-network=" + network_name)

            port_range = options.get("port_range")
            if port_range:
                argv.append("--port-range=" + port_range)

            docker_images_cache = options.get("docker_images_cache")
            if docker_images_cache:
                argv.append("--docker-images-cache=" + docker_images_cache)

        argv.append(options["broker_address"])

        status = worker.main(argv)

        logger.info("worker stopped")

        return status
